@@ -14,17 +14,15 @@ around 'redirect_after_login_uri' => sub {
         return $self->$orig($c, @args);
     }
     return $c->session->{redirect_to_after_login}
-        ? $c->session->{redirect_to_after_login}
+        ? delete $c->session->{redirect_to_after_login}
         : $self->$orig($c, @args);
 };
 
-sub login_redirect {
+before login_redirect => sub {
     my ($self, $c, $message) = @_;
     $c->flash->{error_msg} = $message; # FIXME - Flash horrible
     $c->session->{redirect_to_after_login} = $c->uri_for($c->action, $c->req->captures, $c->req->args->flatten, $c->req->parameters);
-    $c->response->redirect($c->uri_for($self->action_for("login")));
-    $c->detach;
-}
+};
 
 1;
 
